# Serene Bach plugin for recent comment date and trackback date .
#
# Release 1.00 (Dec 13,2006)
#
# This software is provided as-is. You may use it for commercial or 
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2005-2006 Yujiro Araki

package sb::Plugin::RecentDate;

use sb::Plugin ();
use vars qw($js,@history);

sb::Plugin->register_plugin(
    'lang' => {
        'ja' => 'euc',
        'en' => 'ascii',
    },
    'text' => {
        'type'    => 'cms',
        'name'    => 'RecentDate',
        'text'    => 'Recent comment date and trackback date',
        'author'  => 'Yujiro Araki',
        'detail'  => 'http://www.koikikukan.com/',
        'version' => '1.00',
    },
    'data' => 0,
    'file' => 'recentdate.txt',
);

# register callback function to cms entry point
sb::Plugin->register_content_module(
    'type'     => 'entry',
    'callback' => \&sb::Content::RecentDate::_recent_comment_date,
    'field'    => 'recent_comment_date',
    'name'     => 'RecentDate::recent_comment_date'
);
sb::Plugin->register_content_module(
    'type'     => 'entry',
    'callback' => \&sb::Content::RecentDate::_recent_trackback_date,
    'field'    => 'recent_trackback_date',
    'name'     => 'RecentDate::recent_trackback_date'
);

package sb::Content::RecentDate;

sub _recent_comment_date { # ŐVRgt
    my $cms = shift;
    my $entry = shift;
    my %var = @_;
    my $date = _recent_date('Message',$entry);
    return 0 if !$date;
    $cms->tag('recent_comment_date'=>'<span class="new">'.$date.'</span>');
    return 1;
}

sub _recent_trackback_date { # ŐVgbNobNt
    my $cms = shift;
    my $entry = shift;
    my %var = @_;
    my $date = _recent_date('Trackback',$entry);
    return 0 if !$date;
    $cms->tag('recent_trackback_date'=>'<span class="new">'.$date.'</span>');
    return 1;
}

sub _recent_date {
    my ($id, $entry) = @_;
    my $date;
    my @array = sb::Data->load($id,
        'sort' => 'date',
        'cond' => {'stat' => 1,
                   'eid'  => $entry->id},
        'order'=> 1,
    );
    for (@array) {
        my $entry2 = sb::Data->load('Entry','id'=>$_->eid);
        return if (!$entry2 or $entry2->stat == 0);
        return if (($id eq 'Message') && ($entry2->acm == 0));
        return if (($id eq 'Trackback') && ($entry2->atb == 0));
        $date = $_->date;
        last; # only one.
    }
    return $date;
}

1;
__END__
